Learn R Programming

dupNodes (version 0.3.0)

DNSLbetweenness_for_graph: Computes betweenness via duplication of nodes with self-loops for a graph

Description

Computes the betweenness of nodes in a graph that includes self-loops directly.

Usage

DNSLbetweenness_for_graph(graph.with.self.loops)

Value

A list with DNSLbetweenness values for the nodes in the graph.

Arguments

graph.with.self.loops

An igraph object some of whose nodes have connections with themselves (self-loops).

Details

This method computes betweenness centrality via the duplicated nodes method mm24:intra_family_linksdupNodes for a `igraph` object. Use it when you want to just apply the DNSLbetweenness method to an already built graph. The intermediate graph obtained by duplicating nodes is hidden and discarded.

References

Examples

Run this code
library(igraph)
V1 <- c("A", "A","B","C","D","E")
V2 <- c("A", "B","C","D","E","A")
print(DNSLbetweenness_for_graph(graph_from_data_frame(data.frame(V1,V2))))

Run the code above in your browser using DataLab