Learn R Programming

dupNodes (version 0.3.0)

florentine.sn: Data on matrimonial and commercial links of Florentine families

Description

Florentine matrimonial links as an igraph object; it includes marriages as well as commercial links between Florentine families.

Usage

data("florentine.sn")

Arguments

Value

A list that can be used as an igraph object, with noble family names as vertices and edges indicating links.

Author

J. J. Merelo

Details

Florentine matrimonial links as an igraph object; it includes marriages as well as commercial links between Florentine families as recorded by Padgett and Ansell padgett1993robustdupNodes and published by Wang2022dupNodes. It has been enriched with the Medici family genealogy, adding a single self-loop to it.

This is an igraph object where vertices are Florentine families, and edges link two families that have some kind of relationship, either matrimonial or commercial.

References

See Also

link{doges}

Examples

Run this code
library(dupNodes)
library(igraph)
data("florentine.sn")

# All families linked to the Medici
incident(florentine.sn,as.numeric(V(florentine.sn)["MEDICI"]))

# Self loops
E(florentine.sn)[which_loop(florentine.sn)]

Run the code above in your browser using DataLab