A list with betweenness values indexed by node name
Arguments
df
A data frame that should include at least two columns with the names of the nodes
first.node
The column that indicates the node that's linked
second.node
The column that indicates the other node that's linked
Details
This method computes betweenness centrality of a social network described by a data frame. Use it when you want to just apply the DNSLbetweenness method mm24:intra_family_linksdupNodes to a data set, without using the intermediate graph obtained by duplicating nodes.